summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorWisley Chen <wisley.chen@quantatw.com>2019-08-23 18:20:37 +0800
committerJustin TerAvest <teravest@chromium.org>2019-08-23 14:59:37 +0000
commit7f9543f3bb9019deec8c70d4c8d1d84cb7538c27 (patch)
tree0d1e221247fb00c091e0d2f46e21283c752a6a24
parent309cd5931414a82b3b885332c44b25114ca39bba (diff)
downloadchrome-ec-7f9543f3bb9019deec8c70d4c8d1d84cb7538c27.tar.gz
vortininja: Re-assign sku number
Re-assign sku number for vortininja from (4,5,6,7) to (49,50,51,52) BUG=b:138177049 BRANCH=octopus TEST=make buildall -j Change-Id: I1a982a0fa9503bff0a59710bb36311b1799c0ee9 Signed-off-by: Wisley Chen <wisley.chen@quantatw.com> Reviewed-on: https://chromium-review.googlesource.com/c/chromiumos/platform/ec/+/1768479 Reviewed-by: Devin Lu <Devin.Lu@quantatw.com> Reviewed-by: Marco Chen <marcochen@chromium.org> Tested-by: Devin Lu <Devin.Lu@quantatw.com> Tested-by: Marco Chen <marcochen@chromium.org> Commit-Queue: Marco Chen <marcochen@chromium.org>
-rw-r--r--board/meep/board.c8
1 files changed, 4 insertions, 4 deletions
diff --git a/board/meep/board.c b/board/meep/board.c
index edd370fcc9..fad99f5ab1 100644
--- a/board/meep/board.c
+++ b/board/meep/board.c
@@ -210,13 +210,13 @@ unsigned int motion_sensor_count = ARRAY_SIZE(motion_sensors);
/*
* meep is convertible SKU (SKU ID is 1, 2, 3), mimrock is clamshell
* SKU (SKU ID is 17, 18), vortininja is convertible SKU (SKU ID is 4, 5, 6, 7)
* and default SKU is 255 for factory that enable all sensors.
*/
int board_is_convertible(void)
{
- return sku_id == 1 || sku_id == 2 || sku_id == 3 || sku_id == 4 || sku_id == 5 ||
- sku_id == 6 || sku_id == 7 || sku_id == 255;
+ return sku_id == 1 || sku_id == 2 || sku_id == 3 || sku_id == 49 ||
+ sku_id == 50 || sku_id == 51 || sku_id == 52 || sku_id == 255;
}
static void board_update_sensor_config_from_sku(void)
@@ -210,13 +210,13 @@ unsigned int motion_sensor_count = ARRAY_SIZE(motion_sensors);
/*
* meep is convertible SKU (SKU ID is 1, 2, 3), mimrock is clamshell
- * SKU (SKU ID is 17, 18), vortininja is convertible SKU (SKU ID is 4, 5, 6, 7)
- * and default SKU is 255 for factory that enable all sensors.
+ * SKU (SKU ID is 17, 18), vortininja is convertible SKU (SKU ID is 49,
+ * 50, 51, 52) and default SKU is 255 for factory that enable all sensors.
*/
int board_is_convertible(void)